// $Id: consts.cc 5640 2013-11-22 17:00:10Z rafisol $
//
// Copyright (C) 2009-2010  Rafael Ostertag
//
// This file is part of YAPET.
//
// YAPET is free software: you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// YAPET is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// YAPET.  If not, see <http://www.gnu.org/licenses/>.
//

#include "consts.h"

using namespace YAPET;

const std::string Consts::default_suffix(".pet");
const std::string Consts::default_rcfilename(".yapet");
const bool Consts::def_filesecurity(true);
const bool Consts::def_allow_lock_quit(true);
const YAPET::PWGEN::RNGENGINE Consts::def_pwgen_rng(YAPET::PWGEN::AUTO);
